.. _capi-cell:

Function manipulating ``CHFL_CELL``
-----------------------------------

.. doxygentypedef:: CHFL_CELL

.. doxygenfunction:: chfl_cell

.. doxygenfunction:: chfl_cell_triclinic

.. doxygenfunction:: chfl_cell_from_frame

.. doxygenfunction:: chfl_cell_copy

.. doxygenfunction:: chfl_cell_volume

.. doxygenfunction:: chfl_cell_lengths

.. doxygenfunction:: chfl_cell_set_lengths

.. doxygenfunction:: chfl_cell_angles

.. doxygenfunction:: chfl_cell_set_angles

.. doxygenfunction:: chfl_cell_matrix

.. doxygenenum:: chfl_cellshape

.. doxygenfunction:: chfl_cell_shape

.. doxygenfunction:: chfl_cell_set_shape

.. doxygenfunction:: chfl_cell_wrap

.. doxygenfunction:: chfl_cell_free
